@@ -55,8 +55,22 @@ PYPI_API_JSON = "https://pypi.org/pypi/{name}/json"
 
 # read add-on list
 
-INTERNAL_LIBRARIES = [a.strip() for a in open(os.path.join(package_dirname("oasys.application"), "data", "INTERNAL_LIBRARIES.txt"), "rt")]
-INTERNAL_LIBRARIES = [a for a in INTERNAL_LIBRARIES if a]
+INTERNAL_LIBRARIES = []
+MAX_VERSION        = {}
+
+if sys.version[:3]=="3.8": internal_libraries_file = "INTERNAL_LIBRARIES_PY38.txt"
+else: internal_libraries_file = "INTERNAL_LIBRARIES_PY37.txt"
+
+for a in open(os.path.join(package_dirname("oasys.application"), "data", internal_libraries_file), "rt"):
+    a = a.strip()
+    if a:
+        a = a.split(sep="==")
+        library_name = a[0]
+        INTERNAL_LIBRARIES.append(library_name)
+        if len(a) == 2:
+            MAX_VERSION[library_name] = a[1]
+        else:
+            MAX_VERSION[library_name] = None
 
 # query PyPI
 
@@ -78,9 +92,22 @@ log = logging.getLogger(__name__)
 
 from oasys.application.addons import Uninstall, Upgrade, Install
 from oasys.application.addons import OSX_NSURL_toLocalFile, Installer
-from oasys.application.addons import get_meta_from_archive, cleanup, TristateCheckItemDelegate, is_updatable, method_queued, unique
+from oasys.application.addons import get_meta_from_archive, cleanup, TristateCheckItemDelegate, method_queued, unique
 from oasys.application.addons import Installed, Installable, Available
 
+def is_updatable(item):
+    if isinstance(item, Available) or item.installable is None:
+        return False
+    inst, dist = item
+    try:
+        if version.StrictVersion(dist.version) < version.StrictVersion(inst.version):
+            if MAX_VERSION[dist.project_name] is None: return True
+            else: return version.StrictVersion(MAX_VERSION[dist.project_name]) >= version.StrictVersion(inst.version)
+    except ValueError:
+        if version.LooseVersion(dist.version) < version.LooseVersion(inst.version):
+            if MAX_VERSION[dist.project_name] is None: return True
+            else: return version.LooseVersion(MAX_VERSION[dist.project_name]) >= version.LooseVersion(inst.version)
+
 class InternalLibrariesManagerWidget(QWidget):
 
     statechanged = Signal()
