@@ -91,8 +91,13 @@ from matplotlib import MatplotlibDeprecationWarning
 warnings.filterwarnings("ignore",category=MatplotlibDeprecationWarning)
 warnings.filterwarnings("ignore",category=RuntimeWarning)
 
+import sys
+
 def main(argv=None):
 
+    # prevents OASYS to crash on large worskpaces (too many widgets)
+    sys.setrecursionlimit(10000)
+
     # PREVENTS MESSAGING FROM THREADING PROBLEMS IN MATPLOTLIB:
     # The process has forked and you cannot use this CoreFoundation functionality safely. You MUST exec().
     # Break on __THE_PROCESS_HAS_FORKED_AND_YOU_CANNOT_USE_THIS_COREFOUNDATION_FUNCTIONALITY___YOU_MUST_EXEC__() to debug.
@@ -268,7 +273,8 @@ def main(argv=None):
         dirpath = os.path.abspath(os.path.dirname(orangecanvas.__file__))
         QDir.addSearchPath("canvas_icons", os.path.join(dirpath, "icons"))
 
-        no_update = QSettings().value("startup/no-update-inner-libraries", False, type=bool) or options.no_update
+        if not options.no_update is None: no_update = options.no_update
+        else: no_update = QSettings().value("startup/no-update-inner-libraries", False, type=bool)
 
         canvas_window = OASYSMainWindow(parent=None, no_update=no_update)
         canvas_window.setWindowIcon(config.application_icon())
