@@ -1,5 +1,9 @@
 import os, numpy
-from PyQt5 import QtCore, QtWidgets, QtGui
+
+try:
+    from PyQt5 import QtCore, QtWidgets, QtGui
+except:
+    pass
 
 class TriggerOut:
     def __init__(self, new_object=False, additional_parameters={}):
@@ -54,14 +58,17 @@ class TTYGrabber:
         os.close(self.outfile)
         os.remove(self.tmpFileName)
 
-class EmittingStream(QtCore.QObject):
-    textWritten = QtCore.pyqtSignal(str)
+try:
+    class EmittingStream(QtCore.QObject):
+        textWritten = QtCore.pyqtSignal(str)
 
-    def write(self, text):
-        self.textWritten.emit(str(text))
+        def write(self, text):
+            self.textWritten.emit(str(text))
 
-    def flush(self):
-        pass
+        def flush(self):
+            pass
+except:
+    pass
 
 import h5py, time
 
